progs/catastrophic/catastrophic.rb
changeset 753 d94fdbef1a4f
parent 742 b5b5583a3a08
--- a/progs/catastrophic/catastrophic.rb	Tue Sep 01 16:00:37 2020 +0100
+++ b/progs/catastrophic/catastrophic.rb	Wed Sep 02 23:34:19 2020 +0100
@@ -1,3 +1,5 @@
+#!/usr/bin/env ruby
+
 # A case of catastrophic backtracking in Ruby
 #---------------------------------------------
 # example provided by Daniel Baldwin
@@ -8,12 +10,12 @@
 #
 # run on the command line with:
 #
-# ruby catastrophic.rb
+# ./catastrophic.rb
 #
 
-nums = (1..1000)
+nums = (1..30)
 
 #iterate through the nums 1-1000
 nums.each do |i|
 
 	start_time = Time.now
@@ -8,12 +10,12 @@
 
-#iterate through the nums 1-1000
+#iterate through the nums 1-30
 nums.each do |i|
 